# coding: utf-8

"""
    VNS3:ms API

    Cohesive networks VNS3 provides complete control of your network's addresses, routes, rules and edge. Networking does  # noqa: E501

    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

from cohesivenet.api_builder import VersionRouter


def get_vns3_snapshots(
    api_client,
    vns3_controller_id=None,
    vns3_topology_id=None,
    snapshot_id=None,
    **kwargs
):  # noqa: E501
    """get_vns3_snapshots  # noqa: E501

    Return a list of available snapshot files grouped by
    VNS3 controller (optionally filtered by VNS3 controller)  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_vns3_snapshots(async_req=True)

    :param VNS3Client api_client: (required)
    :param vns3_controller_id int: Filter by controller
    :param vns3_topology_id int: Filter by topology
    :param snapshot_id int: Filter by snapshot
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = ["vns3_controller_id", "vns3_topology_id", "snapshot_id"]

    collection_formats = {}

    path_params = {}

    query_params = []
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        query_params.append((param, local_var_params[param]))  # noqa: E501

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/snapshots",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def post_create_vns3_snapshot(
    api_client, vns3_controller_id=None, **kwargs
):  # noqa: E501
    """Create a snapshot for a particular VNS3 Controller  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.post_create_vns3_snapshot(async_req=True)

    :param VNS3Client api_client: (required)
    :param vns3_controller_id int: Controller ID to snapshot (required)
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = ["vns3_controller_id"]

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/snapshots",
        "POST",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def delete_vns3_snapshots(api_client, snapshot_ids=None, **kwargs):  # noqa: E501
    """Delete one or more snapshot files  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.delete_vns3_snapshots(async_req=True)

    :param VNS3Client api_client: (required)
    :param snapshot_ids List[int]: List of snapshot IDs to delete (required)
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = ["snapshot_ids"]

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/snapshots",
        "DELETE",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def get_download_vns3_snapshot(api_client, snapshot_id=None, **kwargs):  # noqa: E501
    """Download a VNS3 snapshot file  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_download_vns3_snapshot(client, async_req=True)

    :param async_req bool: execute request asynchronously
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    request_params = ["snapshot_id"]  # noqa: E501

    collection_formats = {}

    path_params = {}

    query_params = []
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        query_params.append((param, local_var_params[param]))  # noqa: E501

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = None

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["text/plain", "application/octet-stream"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/snapshots/download",
        "GET",
        path_params,
        query_params,
        header_params,
        body={},
        post_params=form_params,
        files=local_var_files,
        response_type="file",
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def get_controller_report(api_client, report_date=None, **kwargs):  # noqa: E501
    """Get controller report  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_controller_report(async_req=True)

    :param VNS3Client api_client: (required)
    :param report_date str: iso8601 datetime to make report for
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = ["report_date"]

    collection_formats = {}

    path_params = {}

    query_params = []
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        query_params.append((param, local_var_params[param]))  # noqa: E501

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}

    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/system/controller_report",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def get_vns3_controllers(
    api_client, vns3_controller_id=None, vns3_topology_id=None, **kwargs
):  # noqa: E501
    """get_vns3_controllers  # noqa: E501

     Return list of all (accessible) VNS3 Controllers  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_vns3_controllers(async_req=True)

    :param VNS3Client api_client: (required)
    :param vns3_controller_id int: Get single controller ID
    :param vns3_topology_id int: Filter by Topology
    :param async_req bool: execute request asynchronously
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    request_params = ["vns3_controller_id", "vns3_topology_id"]  # noqa: E501

    collection_formats = {}

    path_params = {}

    query_params = []
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        query_params.append((param, local_var_params[param]))  # noqa: E501

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = None
    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/vns3_controllers",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def post_add_vns3_controller(
    api_client,
    name=None,
    vns3_topology_id=None,
    address=None,
    active=None,
    api_v1_key=None,
    description=None,
    **kwargs
):  # noqa: E501
    """post_add_vns3_controller  # noqa: E501

    Add VNS3 Controller to a VNS3 topology for management  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_vns3_controllers(async_req=True)

    :param VNS3Client api_client: (required)
    :param name str: VNS3 controller name (required)
    :param vns3_topology_id int: Topology controller is in (required)
    :param address str: IP address or DNS for controller (required)
    :param active bool: Active state
    :param api_v1_key str: Controller's API key
    :param description str: Description for controller
    :param async_req bool: execute request asynchronously
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    request_params = [
        "name",
        "vns3_topology_id",
        "address",
        "active",
        "api_v1_key",
        "description",
    ]  # noqa: E501

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/vns3_controllers",
        "POST",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def get_vns3_controller(api_client, vns3_controller_id, **kwargs):  # noqa: E501
    """Return specific VNS3 Controller details  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_vns3_controller(id, async_req=True)

    :param VNS3Client api_client: (required)
    :param vns3_controller_id int: Controller ID (required)
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = []

    collection_formats = {}

    path_params = {"vns3_controller_id": vns3_controller_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/vns3_controllers/{vns3_controller_id}",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def put_update_vns3_controller(
    api_client,
    vns3_controller_id,
    name=None,
    vns3_topology_id=None,
    address=None,
    active=None,
    api_v1_key=None,
    description=None,
    **kwargs
):  # noqa: E501
    """Update specified VNS3 Controller  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.put_update_vns3_controller(async_req=True)

    :param VNS3Client api_client: (required)
    :param vns3_controller_id int: Controller ID (required)
    :param name str: VNS3 controller name
    :param vns3_topology_id int: Topology controller is in
    :param address str: IP address or DNS for controller
    :param active bool: Active state
    :param api_v1_key str: Controller's APIv1 key
    :param description str: Description for controller
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = [
        "name",
        "vns3_topology_id",
        "address",
        "active",
        "api_v1_key",
        "description",
    ]

    collection_formats = {}

    path_params = {"vns3_controller_id": vns3_controller_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/vns3_controllers/{vns3_controller_id}",
        "PUT",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def delete_vns3_controller(api_client, vns3_controller_id, **kwargs):  # noqa: E501
    """Delete VNS3 Controller from topology  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.delete_vns3_controller(id, async_req=True)

    :param VNS3Client api_client: (required)
    :param vns3_controller_id int: Controller ID (required)
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = []

    collection_formats = {}

    path_params = {"vns3_controller_id": vns3_controller_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/vns3_controllers/{vns3_controller_id}",
        "DELETE",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def get_vns3_controller_status(api_client, vns3_controller_id, **kwargs):  # noqa: E501
    """Get VNS3 controller status  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_vns3_controller_status(id, async_req=True)

    :param VNS3Client api_client: (required)
    :param vns3_controller_id int: Controller ID (required)
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = []

    collection_formats = {}

    path_params = {"vns3_controller_id": vns3_controller_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/vns3_controllers/{vns3_controller_id}/status",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def put_vns3_controller_api_password(
    api_client, vns3_controller_id, api_password=None, **kwargs
):  # noqa: E501
    """Update VNS3 Controller API password  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.put_vns3_controller_api_password(id, async_req=True)

    :param VNS3Client api_client: (required)
    :param vns3_controller_id int: Controller ID (required)
    :param api_password str: New api password (required)
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = ["api_password"]

    collection_formats = {}

    path_params = {"vns3_controller_id": vns3_controller_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/vns3_controllers/{vns3_controller_id}/update_api_password",
        "PUT",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def put_vns3_controller_ui(
    api_client,
    vns3_controller_id,
    username=None,
    password=None,
    ui_enabled=None,
    **kwargs
):  # noqa: E501
    """Update VNS3 Controller UI config  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.put_vns3_controller_ui(id, async_req=True)

    :param VNS3Client api_client: (required)
    :param vns3_controller_id int: Controller ID (required)
    :param username str: Update UI username
    :param password str: Update UI password
    :param ui_enabled bool: Enable/Disable UI
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = ["username", "password", "ui_enabled"]

    collection_formats = {}

    path_params = {"vns3_controller_id": vns3_controller_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/vns3_controllers/{vns3_controller_id}/update_ui",
        "PUT",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def get_vns3_controller_ha_details(
    api_client, vns3_controller_id, **kwargs
):  # noqa: E501
    """GET VNS3 Controller HA status  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_vns3_controller_ha_details(id, async_req=True)

    :param VNS3Client api_client: (required)
    :param vns3_controller_id int: Controller ID (required)
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = []

    collection_formats = {}

    path_params = {"vns3_controller_id": vns3_controller_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/vns3_controllers/{vns3_controller_id}/ha",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def put_update_vns3_controller_ha(
    api_client,
    vns3_controller_id,
    ha_enabled=None,
    ha_type=None,
    ha_uuid=None,
    ha_backup_ip_address=None,
    ha_api_v1_key=None,
    ha_instance_id=None,
    ha_image_id=None,
    ha_cloud_cred_id=None,
    stop_old_primary=None,
    **kwargs
):  # noqa: E501
    """Update HA details for specified VNS3 controller  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.put_update_vns3_controller_ha(id, async_req=True)

    :param VNS3Client api_client: (required)
    :param vns3_controller_id int: Controller ID (required)
    :param ha_enabled bool: Enable/Disable HA (required)
    :param ha_type str: Hot, warm or Cold
    :param ha_uuid str: HA UUID of the VNS3 failover box for hot HA. Required for hot HA.
    :param ha_backup_ip_address str: HA Backup server IP address. Required for hot HA.
    :param ha_api_v1_key str: Controller's APIv1 key
    :param ha_instance_id str: VNS3 standby instance for warm HA. Required for warm HA.
    :param ha_image_id str: VNS3 image ID for Cold HA. Required for cold HA.
    :param ha_cloud_cred_id str: Cloud credential ID
    :param stop_old_primary bool: Should stop old primary?
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = [
        "ha_enabled",
        "ha_type",
        "ha_uuid",
        "ha_backup_ip_address",
        "ha_api_v1_key",
        "ha_instance_id",
        "ha_image_id",
        "ha_cloud_cred_id",
        "stop_old_primary",
    ]

    collection_formats = {}

    path_params = {"vns3_controller_id": vns3_controller_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/vns3_controllers/{vns3_controller_id}/ha",
        "PUT",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def put_validate_vns3_controller_ha(
    api_client, vns3_controller_id, **kwargs
):  # noqa: E501
    """Validate HA configuration for specified VNS3 controller  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.put_validate_vns3_controller_ha(id, async_req=True)

    :param VNS3Client api_client: (required)
    :param vns3_controller_id int: Controller ID (required)
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = []

    collection_formats = {}

    path_params = {"vns3_controller_id": vns3_controller_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/vns3_controllers/{vns3_controller_id}/ha/validate",
        "PUT",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def put_init_vns3_controller_ha(api_client, vns3_controller_id, **kwargs):  # noqa: E501
    """Initialise HA for specified VNS3 controller and its backup device, set up pairing and configuration  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.put_init_vns3_controller_ha(id, async_req=True)

    :param VNS3Client api_client: (required)
    :param vns3_controller_id int: Controller ID (required)
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = []

    collection_formats = {}

    path_params = {"vns3_controller_id": vns3_controller_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/vns3_controllers/{vns3_controller_id}/ha/initialise",
        "PUT",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def put_sync_vns3_controller_ha(
    api_client, vns3_controller_id, sync_type=None, **kwargs
):  # noqa: E501
    """Initialise HA for specified VNS3 controller and its backup device, set up pairing and configuration  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.put_sync_vns3_controller_ha(id, async_req=True)

    :param VNS3Client api_client: (required)
    :param vns3_controller_id int: Controller ID (required)
    :param sync_type str: Type of sync to perform: full, pull or push (required)
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = ["sync_type"]

    collection_formats = {}

    path_params = {"vns3_controller_id": vns3_controller_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/vns3_controllers/{vns3_controller_id}/ha/sync",
        "PUT",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def put_activate_vns3_controller_ha(
    api_client, vns3_controller_id, sync_type=None, **kwargs
):  # noqa: E501
    """Trigger the HA switchover activation  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.put_activate_vns3_controller_ha(id, async_req=True)

    :param VNS3Client api_client: (required)
    :param vns3_controller_id int: Controller ID (required)
    :param sync_type str: Type of sync to perform: full, pull or push (required)
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = []

    collection_formats = {}

    path_params = {"vns3_controller_id": vns3_controller_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/vns3_controllers/{vns3_controller_id}/ha/activate",
        "PUT",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def get_vns3_controller_ha_status(
    api_client, vns3_controller_id, **kwargs
):  # noqa: E501
    """Get status of VNS3 HA failover  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_vns3_controller_ha_status(id, async_req=True)

    :param VNS3Client api_client: (required)
    :param vns3_controller_id int: Controller ID (required)
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = []

    collection_formats = {}

    path_params = {"vns3_controller_id": vns3_controller_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/vns3_controllers/{vns3_controller_id}/ha/activate",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


class VNS3ManagementApiRouter(VersionRouter):
    """Manage VNS3 controllers in your network topology, automating snapshots, HA and more"""

    function_library = {
        "get_vns3_snapshots": {"2.1.1-2.3.5": get_vns3_snapshots},
        "post_create_vns3_snapshot": {"2.1.1-2.3.5": post_create_vns3_snapshot},
        "delete_vns3_snapshots": {"2.1.1-2.3.5": delete_vns3_snapshots},
        "get_download_vns3_snapshot": {"2.1.1-2.3.5": get_download_vns3_snapshot},
        "get_controller_report": {"2.1.1-2.3.5": get_controller_report},
        "get_vns3_controllers": {"2.1.1-2.3.5": get_vns3_controllers},
        "post_add_vns3_controller": {"2.1.1-2.3.5": post_add_vns3_controller},
        "get_vns3_controller": {"2.1.1-2.3.5": get_vns3_controller},
        "put_update_vns3_controller": {"2.1.1-2.3.5": put_update_vns3_controller},
        "delete_vns3_controller": {"2.1.1-2.3.5": delete_vns3_controller},
        "get_vns3_controller_status": {"2.1.1-2.3.5": get_vns3_controller_status},
        "put_vns3_controller_api_password": {
            "2.1.1-2.3.5": put_vns3_controller_api_password
        },
        "put_vns3_controller_ui": {"2.1.1-2.3.5": put_vns3_controller_ui},
        "get_vns3_controller_ha_details": {
            "2.1.1-2.3.5": get_vns3_controller_ha_details
        },
        "put_update_vns3_controller_ha": {"2.1.1-2.3.5": put_update_vns3_controller_ha},
        "put_validate_vns3_controller_ha": {
            "2.1.1-2.3.5": put_validate_vns3_controller_ha
        },
        "put_init_vns3_controller_ha": {"2.1.1-2.3.5": put_init_vns3_controller_ha},
        "put_sync_vns3_controller_ha": {"2.1.1-2.3.5": put_sync_vns3_controller_ha},
        "get_vns3_controller_ha_status": {"2.1.1-2.3.5": get_vns3_controller_ha_status},
        "put_activate_vns3_controller_ha": {
            "2.1.1-2.3.5": put_activate_vns3_controller_ha
        },
    }



# coding: utf-8

"""
    VNS3:ms API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import pytest

import cohesivenet
from cohesivenet.api.vns3ms import administration_api  # noqa: E501
from cohesivenet.rest import ApiException

from tests.vns3ms.stub_data import AdminApiData
from tests.openapi import generate_method_test


class TestMSAdminApi(object):
    """VNS3:ms Admin API unit tests"""

    def test_put_enable_ldap(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for put_enable_ldap
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/admin/ldap",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={
                "response_type": "success",
                "response": {"ldap_enabled": False},
            },
        )(administration_api.put_enable_ldap)

    def test_get_ldap_settings(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for get_ldap_settings
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/admin/ldap/settings",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=AdminApiData.LdapSettingsResponse,
        )(administration_api.get_ldap_settings)

    def test_put_ldap_settings(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for put_ldap_settings
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/admin/ldap/settings",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={"response_type": "success", "response": "Settings updated"},
        )(administration_api.put_ldap_settings)

    def test_post_validate_ldap_settings(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for post_validate_ldap_settings
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "POST",
            "/admin/ldap/settings",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={
                "response_type": "error",
                "response": {
                    "connect_success": False,
                    "message": "Connection timed out - user specified timeout",
                },
            },
        )(administration_api.post_validate_ldap_settings)

    def test_get_ldap_user_schema(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for get_ldap_user_schema
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/admin/ldap/user_schema",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=AdminApiData.LdapUserSchemaResponse,
        )(administration_api.get_ldap_user_schema)

    def test_put_ldap_user_schema(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for put_ldap_user_schema
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/admin/ldap/user_schema",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(administration_api.put_ldap_user_schema)

    def test_post_validate_ldap_user_schema(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for post_validate_ldap_user_schema
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "POST",
            "/admin/ldap/user_schema",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={"response_type": "success", "response": ["user"]},
        )(administration_api.post_validate_ldap_user_schema)

    def test_get_ldap_group_schema(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for get_ldap_group_schema
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/admin/ldap/group_schema",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=AdminApiData.LdapGroupSchemaResponse,
        )(administration_api.get_ldap_group_schema)

    def test_put_ldap_group_schema(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for put_ldap_group_schema
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/admin/ldap/group_schema",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(administration_api.put_ldap_group_schema)

    def test_post_validate_ldap_group_schema(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for post_validate_ldap_group_schema
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "POST",
            "/admin/ldap/group_schema",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={"response_type": "success", "response": ["group"]},
        )(administration_api.post_validate_ldap_group_schema)



# coding: utf-8

"""
    VNS3:ms API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import pytest

import cohesivenet
from cohesivenet.api.vns3ms import system_api  # noqa: E501
from cohesivenet.rest import ApiException

from tests.openapi import generate_method_test
from tests.vns3ms.stub_data import SystemApiData


class TestMSSystemApi(object):
    """VNS3:ms System API unit tests"""

    def test_get_remote_support_details(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for get_remote_support_details
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/system/remote_support",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={
                "response_type": "success",
                "response": {"remote_support_enabled": False},
            },
        )(system_api.get_remote_support_details)

    def test_put_remote_support(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for put_remote_support
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/system/remote_support",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(system_api.put_remote_support)

    def test_get_remote_support_keypair_details(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for get_remote_support_keypair_details
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/system/remote_support/keypair",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(system_api.get_remote_support_keypair_details)

    def test_post_generate_remote_support_keypair(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for post_generate_remote_support_keypair
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "POST",
            "/system/remote_support/keypair",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(system_api.post_generate_remote_support_keypair)

    def test_delete_remote_support_keypair(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for delete_remote_support_keypair
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "DELETE",
            "/system/remote_support/keypair",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={
                "response_type": "success",
                "response": {"keypair_installed": False},
            },
        )(system_api.delete_remote_support_keypair)

    def test_get_system_status(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for get_system_status
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/system/status",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(system_api.get_system_status)

    def test_get_credential_types(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for get_credential_types
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/system/credential_types",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={
                "response_type": "success",
                "response": [{"name": "EC2", "code": "ec2"}],
            },
        )(system_api.get_credential_types)

    def test_get_credential_type_details(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for get_credential_type_details
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/system/credential_types/{code}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=SystemApiData.CredTypeDetails,
        )(system_api.get_credential_type_details)

    def test_get_system_ntp_hosts(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for get_system_ntp_hosts
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/system/ntp_hosts",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=SystemApiData.NTPHosts,
        )(system_api.get_system_ntp_hosts)

    def test_post_add_ntp_host(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for post_add_ntp_host
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "POST",
            "/system/ntp_hosts",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(system_api.post_add_ntp_host)

    def test_delete_ntp_host(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for delete_ntp_host
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "DELETE",
            "/system/ntp_hosts/{host_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(system_api.delete_ntp_host)

    def test_delete_ssl_install(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for delete_ssl_install
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "DELETE",
            "/system/ssl",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(system_api.delete_ssl_install)

    def test_get_ssl_install_status(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for get_ssl_install_status
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/system/ssl/install/{uuid}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(system_api.get_ssl_install_status)

    def test_put_upload_ssl_certs(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for put_upload_ssl_certs
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/system/ssl/keypair",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(system_api.put_upload_ssl_certs)

    def test_put_install_ssl_certs(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for put_install_ssl_certs
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/system/ssl/install",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(system_api.put_install_ssl_certs)

    def test_get_job_status(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for get_job_status
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/system/jobs/{uuid}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(system_api.get_job_status)



# coding: utf-8

"""
    VNS3:ms API

    Cohesive networks VNS3 provides complete control of your network's addresses, routes, rules and edge. Networking does  # noqa: E501

    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

from cohesivenet.api_builder import VersionRouter


def get_cloud_vlan_components(
    api_client, cloud_vlan_component_id=None, **kwargs
):  # noqa: E501
    """Return list of all (accessible) Cloud VLAN Components  # noqa: E501

    Return list of all (accessible) Cloud VLAN Components  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_cloud_vlan_components(async_req=True)

    :param VNS3Client api_client: (required)
    :param cloud_vlan_component_id int: Cloud VLAN Component ID for filtering
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = ["cloud_vlan_component_id"]

    collection_formats = {}

    path_params = {}

    query_params = []
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        query_params.append((param, local_var_params[param]))  # noqa: E501

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/cloud_vlan_components",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def post_create_vlan_component(
    api_client,
    name=None,
    cloud_vlan_id=None,
    user_cred_id=None,
    vlan_component_id=None,
    region=None,
    description=None,
    **kwargs
):  # noqa: E501
    """Create new Cloud VLAN Component  # noqa: E501

    Create new Cloud VLAN Component  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.post_create_vlan_component(async_req=True)

    :param VNS3Client api_client: (required)
    :param name str: Cloud VLAN Component name (required)
    :param cloud_vlan_id int: Parent Cloud VLAN ID (required)
    :param user_cred_id int: User credential ID (required)
    :param vlan_component_id int: Component ID defined by cloud associated with user credential
    :param region str: Cloud VLAN component region
    :param description str: Component description
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = [
        "name",
        "cloud_vlan_id",
        "user_cred_id",
        "vlan_component_id",
        "region",
        "description",
    ]

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/cloud_vlan_components",
        "POST",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def get_cloud_vlan_component(api_client, component_id, **kwargs):  # noqa: E501
    """Return specific Cloud VLAN Components details  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_cloud_vlan_component(id, async_req=True)

    :param VNS3Client api_client: (required)
    :param component_id int: VLAN component ID (required)
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = []

    collection_formats = {}

    path_params = {"component_id": component_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/cloud_vlan_components/{component_id}",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def put_update_vlan_component(
    api_client,
    component_id,
    name=None,
    cloud_vlan_id=None,
    user_cred_id=None,
    region=None,
    description=None,
    **kwargs
):  # noqa: E501
    """Update specified Cloud VLAN Component  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.put_update_vlan_component(async_req=True)

    :param VNS3Client api_client: (required)
    :param name str: Cloud VLAN Component name (required)
    :param cloud_vlan_id int: Parent Cloud VLAN ID (required)
    :param user_cred_id int: User credential ID (required)
    :param region str: Cloud VLAN component region
    :param description str: Component description
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = ["name", "cloud_vlan_id", "user_cred_id", "region", "description"]

    collection_formats = {}

    path_params = {"component_id": component_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/cloud_vlan_components/{component_id}",
        "PUT",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def delete_vlan_component(api_client, component_id, **kwargs):  # noqa: E501
    """Delete Cloud VLAN Components  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.delete_vlan_component(id, async_req=True)

    :param VNS3Client api_client: (required)
    :param component_id int: VLAN component ID (required)
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = []

    collection_formats = {}

    path_params = {"component_id": component_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/cloud_vlan_components/{component_id}",
        "DELETE",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def get_cloud_vlans(api_client, cloud_vlan_id=None, **kwargs):  # noqa: E501
    """Return list of all (accessible) Cloud VLANs  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_cloud_vlans(async_req=True)

    :param VNS3Client api_client: (required)
    :param cloud_vlan_id int: Cloud VLAN ID for filtering
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = ["cloud_vlan_id"]

    collection_formats = {}

    path_params = {}

    query_params = []
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        query_params.append((param, local_var_params[param]))  # noqa: E501

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/cloud_vlans",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def post_create_cloud_vlan(
    api_client, name=None, virtual_network_id=None, description=None, **kwargs
):  # noqa: E501
    """Create new Cloud VLAN  # noqa: E501

    Create new Cloud VLAN  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.post_create_cloud_vlan(async_req=True)

    :param VNS3Client api_client: (required)
    :param name str: Cloud VLAN name (required)
    :param virtual_network_id int: Parent Virtual Network ID (required)
    :param description str: VLAN description
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = ["name", "virtual_network_id", "description"]

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/cloud_vlans",
        "POST",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def get_cloud_vlan(api_client, vlan_id, **kwargs):  # noqa: E501
    """Return specific Cloud VLAN details  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_cloud_vlan(vlan_id, async_req=True)

    :param VNS3Client api_client: (required)
    :param vlan_id int: Cloud VLAN ID (required)
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = []

    collection_formats = {}

    path_params = {"vlan_id": vlan_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/cloud_vlans/{vlan_id}",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def put_update_cloud_vlan(
    api_client, vlan_id, name=None, virtual_network_id=None, description=None, **kwargs
):  # noqa: E501
    """Update specified Cloud VLAN Component  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.put_update_cloud_vlan(async_req=True)

    :param VNS3Client api_client: (required)
    :param vlan_id int: Cloud VLAN ID (required)
    :param name str: Cloud VLAN name (required)
    :param virtual_network_id int: Parent Virtual Network ID (required)
    :param description str: VLAN description
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = ["name", "virtual_network_id", "description"]

    collection_formats = {}

    path_params = {"vlan_id": vlan_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/cloud_vlans/{vlan_id}",
        "PUT",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def delete_cloud_vlan(api_client, vlan_id, **kwargs):  # noqa: E501
    """Delete Cloud VLAN  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.delete_cloud_vlan(id, async_req=True)

    :param VNS3Client api_client: (required)
    :param vlan_id int: Cloud VLAN ID (required)
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = []

    collection_formats = {}

    path_params = {"vlan_id": vlan_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/cloud_vlans/{vlan_id}",
        "DELETE",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def get_virtual_networks(api_client, virtual_network_id=None, **kwargs):  # noqa: E501
    """Return list of all (accessible) Virtual Networks  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_virtual_networks(async_req=True)

    :param VNS3Client api_client: (required)
    :param virtual_network_id int: Virtual Network ID for filtering
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = ["virtual_network_id"]

    collection_formats = {}

    path_params = {}

    query_params = []
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        query_params.append((param, local_var_params[param]))  # noqa: E501

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/virtual_networks",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def post_create_virtual_network(
    api_client, name=None, description=None, **kwargs
):  # noqa: E501
    """Create new Virtual Network  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.post_create_virtual_network(async_req=True)

    :param VNS3Client api_client: (required)
    :param name str: Virtual network name (required)
    :param description str: Network description
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = ["name", "description"]

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/virtual_networks",
        "POST",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def get_virtual_network(api_client, virtual_network_id, **kwargs):  # noqa: E501
    """Return specific Virtual Network details  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_virtual_network(virtual_network_id, async_req=True)

    :param VNS3Client api_client: (required)
    :param virtual_network_id int: Virtual network ID (required)
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = []

    collection_formats = {}

    path_params = {"virtual_network_id": virtual_network_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/virtual_networks/{virtual_network_id}",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def put_update_virtual_network(
    api_client, virtual_network_id, name=None, description=None, **kwargs
):  # noqa: E501
    """Update specified Virtual Network  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.put_update_virtual_network(async_req=True)

    :param VNS3Client api_client: (required)
    :param virtual_network_id int: Virtual network ID (required)
    :param name str: Virtual network name
    :param description str: Network description
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = ["name", "description"]

    collection_formats = {}

    path_params = {"virtual_network_id": virtual_network_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/virtual_networks/{virtual_network_id}",
        "PUT",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def delete_virtual_network(api_client, virtual_network_id, **kwargs):  # noqa: E501
    """Delete Virtual Network # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.delete_virtual_network(virtual_network_id, async_req=True)

    :param VNS3Client api_client: (required)
    :param virtual_network_id int: Virtual network ID (required)
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = []

    collection_formats = {}

    path_params = {"virtual_network_id": virtual_network_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/virtual_networks/{virtual_network_id}",
        "DELETE",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def get_export_virtual_networks(api_client):  # noqa: E501
    """Export virtual networks CSV  # noqa: E501

    Export virtual networks CSV file   # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_export_virtual_networks(client, async_req=True)

    :param async_req bool: execute request asynchronously
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    request_params = []  # noqa: E501

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = None

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["text/plain", "application/octet-stream"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/virtual_networks/export",
        "GET",
        path_params,
        query_params,
        header_params,
        body={},
        post_params=form_params,
        files=local_var_files,
        response_type="file",
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def post_import_virtual_networks(api_client, body=None):  # noqa: E501
    """Import virtual networks from CSV file  # noqa: E501

    Import virtual networks from CSV file   # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.post_import_virtual_networks(client, body, async_req=True)

    :param async_req bool: execute request asynchronously
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    request_params = []  # noqa: E501

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = body

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["text/plain"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/virtual_networks/import",
        "POST",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def get_vns3_topologies(api_client, vns3_topology_id=None, **kwargs):  # noqa: E501
    """Return list of all (accessible) VNS3 Topologies  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_vns3_topologies(async_req=True)

    :param VNS3Client api_client: (required)
    :param vns3_topology_id int: Topology ID for filtering
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = ["vns3_topology_id"]

    collection_formats = {}

    path_params = {}

    query_params = []
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        query_params.append((param, local_var_params[param]))  # noqa: E501

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/vns3_topologies",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def post_create_vns3_topology(
    api_client, name=None, virtual_network_id=None, description=None, **kwargs
):  # noqa: E501
    """Create new VNS3 Topology # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.post_create_vns3_topology(async_req=True)

    :param VNS3Client api_client: (required)
    :param name str: Topology name name (required)
    :param virtual_network_id int: Parent Virtual Network ID
    :param description str: Topology description
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = ["name", "virtual_network_id", "description"]

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/vns3_topologies",
        "POST",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def get_vns3_topology(api_client, vns3_topology_id, **kwargs):  # noqa: E501
    """Return specific Topology details  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_vns3_topology(vns3_topology_id, async_req=True)

    :param VNS3Client api_client: (required)
    :param vns3_topology_id int: Topology ID (required)
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = []

    collection_formats = {}

    path_params = {"vns3_topology_id": vns3_topology_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/vns3_topologies/{vns3_topology_id}",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def put_update_vns3_topology(
    api_client,
    vns3_topology_id,
    name=None,
    virtual_network_id=None,
    description=None,
    **kwargs
):  # noqa: E501
    """Update specified VNS3 Topology  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.put_update_vns3_topology(async_req=True)

    :param VNS3Client api_client: (required)
    :param vns3_topology_id int: Topology ID (required)
    :param name str: Virtual network name
    :param virtual_network_id int: Parent Virtual Network ID
    :param description str: Network description
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = ["name", "virtual_network_id", "description"]

    collection_formats = {}

    path_params = {"vns3_topology_id": vns3_topology_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/vns3_topologies/{vns3_topology_id}",
        "PUT",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def delete_vns3_topology(api_client, vns3_topology_id, **kwargs):  # noqa: E501
    """Delete Topology # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.delete_vns3_topology(vns3_topology_id, async_req=True)

    :param VNS3Client api_client: (required)
    :param vns3_topology_id int: Topology ID (required)
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = []

    collection_formats = {}

    path_params = {"vns3_topology_id": vns3_topology_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/vns3_topologies/{vns3_topology_id}",
        "DELETE",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def get_webhooks(api_client, **kwargs):  # noqa: E501
    """Return list of all configured webhooks  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_webhooks(async_req=True)

    :param VNS3Client api_client: (required)
    :param cloud_vlan_component_id int: Cloud VLAN Component ID for filtering
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = []

    collection_formats = {}

    path_params = {}

    query_params = []
    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/webhooks",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def post_create_webhook(
    api_client,
    name=None,
    url=None,
    events=None,
    body=None,
    validate_cert=None,
    custom_properties=None,
    headers=None,
    parameters=None,
    **kwargs
):  # noqa: E501
    """Create new Cloud VLAN  # noqa: E501

    Create new Cloud VLAN  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.post_create_cloud_vlan(async_req=True)

    :param VNS3Client api_client: (required)
    :param name str: Webhook name (required)
    :param url str: Webhook endpoint
    :param events List[str]: List of events this webhook supports
    :param body str: POST payload
    :param validate_cert bool: Verify SSL
    :param custom_properties List[{
        name str: (required)
        value str:
        description str:
    }]:
    :param headers List[{
        name str:
        value str:
    }]:
    :param parameters List[{
        name str:
        value str:
    }]:
    :param async_req bool: execute request asynchronously
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()
    request_params = [
        "name",
        "url",
        "events",
        "body",
        "validate_cert",
        "custom_properties",
        "headers",
        "parameters",
    ]

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/webhook",
        "POST",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def get_webhook(api_client, webhook_id, **kwargs):  # noqa: E501
    """get_webhook  # noqa: E501

    Retrieve details for single webhook integration  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_webhook(client, webhook_id, async_req=True)

    :param async_req bool: execute request asynchronously
    :param int webhook_id: ID for webhook integration (required)
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    collection_formats = {}

    path_params = {"webhook_id": webhook_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = None
    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/webhook/{webhook_id}",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def put_update_webhook(
    api_client,
    webhook_id,
    name=None,
    url=None,
    events=None,
    body=None,
    validate_cert=None,
    custom_properties=None,
    headers=None,
    parameters=None,
    **kwargs
):  # noqa: E501
    """put_update_webhook  # noqa: E501

    Edit defined webhook integration  # noqa: E501
    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.put_update_webhook(webhook_id, update_webhook_request, async_req=True)

    :param int webhook_id: ID for webhook integration (required)
    :param name str:
    :param url str:
    :param events List[str]:
    :param body str: Webhook payload
    :param validate_cert bool: execute request asynchronously
    :param custom_properties List[{
        name str: (required)
        value str:
        description str:
    }]:
    :param headers List[{
        name str:
        value str:
    }]:
    :param parameters List[{
        name str:
        value str:
    }]:
    :param async_req bool: execute request asynchronously
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    request_params = [
        "name",
        "url",
        "events",
        "body",
        "validate_cert",
        "custom_properties",
        "headers",
        "parameters",
    ]

    collection_formats = {}

    path_params = {"webhook_id": webhook_id}

    query_params = []

    header_params = {}

    form_params = []

    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/webhook/{webhook_id}",
        "PUT",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def delete_webhook(api_client, webhook_id, **kwargs):  # noqa: E501
    """delete_webhook  # noqa: E501

    Delete defined webhook integration  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.delete_webhook(webhook_id, async_req=True)

    :param int webhook_id: ID for webhook integration (required)
    :param async_req bool: execute request asynchronously
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    collection_formats = {}

    path_params = {"webhook_id": webhook_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = None
    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/webhook/{webhook_id}",
        "DELETE",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def get_alert(api_client, alert_id, **kwargs):  # noqa: E501
    """get_alert  # noqa: E501

    Retrieve details for single alert  # noqa: E501
    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_alert(alert_id, async_req=True)

    :param int alert_id: ID for Alert definition (required)
    :param async_req bool: execute request asynchronously
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    collection_formats = {}

    path_params = {"alert_id": alert_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = None
    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/alert/{alert_id}",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def get_alerts(api_client, **kwargs):  # noqa: E501
    """get_alerts  # noqa: E501

    Retrieve all alerts  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.get_alerts(async_req=True)

    :param async_req bool: execute request asynchronously
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = None
    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/alerts",
        "GET",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def post_create_alert(
    api_client,
    name=None,
    url=None,
    enabled=None,
    events=None,
    custom_properties=None,
    webhook_id=None,
    template_id=None,
    **kwargs
):  # noqa: E501
    """post_create_alert  # noqa: E501

    Define new alert  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True

    >>> response = await api.post_create_alert(client, async_req=True)

    :param name str: (required)
    :param url str: (required)
    :param enabled bool: True by default
    :param events List[str]:
    :param custom_properties List[{
        name str:
        value str:
    }]:
    :param webhook_id int: webhook_id or template_id must be provided. Only webhook_id supported starting with 4.9
    :param template_id int: webhook_id or template_id must be provided. Only webhook_id supported starting with 4.9
    :param async_req bool: execute request asynchronously
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    request_params = [
        "name",
        "url",
        "enabled",
        "events",
        "custom_properties",
        "webhook_id",
        "template_id",
    ]

    collection_formats = {}

    path_params = {}

    query_params = []

    header_params = {}

    form_params = []

    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/alert",
        "POST",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def delete_alert(api_client, alert_id, **kwargs):  # noqa: E501
    """delete_alert  # noqa: E501

    Delete defined alert  # noqa: E501

    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.delete_alert(client, async_req=True)

    :param int alert_id: ID for webhook integration (required)
    :param async_req bool: execute request asynchronously
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    collection_formats = {}

    path_params = {"alert_id": alert_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = None
    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/alert/{alert_id}",
        "DELETE",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def put_update_alert(
    api_client,
    alert_id,
    name=None,
    url=None,
    enabled=None,
    events=None,
    custom_properties=None,
    webhook_id=None,
    template_id=None,
    **kwargs
):  # noqa: E501
    """put_update_alert  # noqa: E501

    Edit defined alert  # noqa: E501
    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.put_update_alert(alert_id, update_alert_request, async_req=True)

    :param async_req bool: execute request asynchronously
    :param int alert_id: ID for Alert definition (required)
    :param name str:
    :param url str:
    :param enabled bool: True by default
    :param events List[str]:
    :param custom_properties List[{
        name str:
        value str:
    }]:
    :param webhook_id int: webhook_id or template_id must be provided. Only webhook_id supported starting with 4.9.
    :param template_id int: webhook_id or template_id must be provided. Only webhook_id supported starting with 4.9.
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    request_params = [
        "name",
        "url",
        "enabled",
        "events",
        "custom_properties",
        "webhook_id",
        "template_id",
    ]

    collection_formats = {}

    path_params = {"alert_id": alert_id}

    query_params = []

    header_params = {}

    form_params = []

    local_var_files = {}

    body_params = {}
    for param in [p for p in request_params if local_var_params.get(p) is not None]:
        body_params[param] = local_var_params[param]

    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # HTTP header `Content-Type`
    header_params["Content-Type"] = api_client.select_header_content_type(  # noqa: E501
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/alert/{alert_id}",
        "PUT",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def post_toggle_enable_alert(api_client, alert_id, **kwargs):  # noqa: E501
    """post_toggle_enable_alert  # noqa: E501

    Toggle enabled property on alert  # noqa: E501
    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.post_toggle_enable_alert(alert_id, async_req=True)

    :param async_req bool: execute request asynchronously
    :param int alert_id: ID for Alert definition (required)
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    collection_formats = {}

    path_params = {"alert_id": alert_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = None
    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/alert/{alert_id}/toggle_enabled",
        "POST",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


def post_test_alert(api_client, alert_id, **kwargs):  # noqa: E501
    """post_test_alert  # noqa: E501

    Send test alert for this defined alert  # noqa: E501
    This method makes a synchronous HTTP request by default. To make an
    asynchronous HTTP request, please pass async_req=True
    >>> response = await api.post_test_alert(client, alert_id, async_req=True)

    :param int alert_id: ID for Alert definition (required)
    :param async_req bool: execute request asynchronously
    :param _return_http_data_only: response data without head status code
                                    and headers
    :param _preload_content: if False, the urllib3.HTTPResponse object will
                                be returned without reading/decoding response
                                data. Default is True.
    :param _request_timeout: timeout setting for this request. If one
                                number provided, it will be total request
                                timeout. It can also be a pair (tuple) of
                                (connection, read) timeouts.
    :return: APIResponse or awaitable if async
    """

    local_var_params = locals()

    collection_formats = {}

    path_params = {"alert_id": alert_id}

    query_params = []

    header_params = {}

    form_params = []
    local_var_files = {}

    body_params = None
    # HTTP header `Accept`
    header_params["Accept"] = api_client.select_header_accept(
        ["application/json"]
    )  # noqa: E501

    # Authentication setting
    auth_settings = ["ApiTokenAuth"]  # noqa: E501

    return api_client.call_api(
        "/alert/{alert_id}/test",
        "POST",
        path_params,
        query_params,
        header_params,
        body=body_params,
        post_params=form_params,
        files=local_var_files,
        response_type="object",  # noqa: E501
        auth_settings=auth_settings,
        async_req=local_var_params.get("async_req"),
        _return_http_data_only=local_var_params.get(
            "_return_http_data_only"
        ),  # noqa: E501
        _preload_content=local_var_params.get("_preload_content", True),
        _request_timeout=local_var_params.get("_request_timeout"),
        collection_formats=collection_formats,
    )


class CloudMonitoringApiRouter(VersionRouter):
    """Configure and monitor your cloud by tracking cloud VPCs and virtual networks"""

    function_library = {
        "get_cloud_vlan_components": {"2.1.1-2.3.5": get_cloud_vlan_components},
        "post_create_vlan_component": {"2.1.1-2.3.5": post_create_vlan_component},
        "get_cloud_vlan_component": {"2.1.1-2.3.5": get_cloud_vlan_component},
        "put_update_vlan_component": {"2.1.1-2.3.5": put_update_vlan_component},
        "delete_vlan_component": {"2.1.1-2.3.5": delete_vlan_component},
        "get_cloud_vlans": {"2.1.1-2.3.5": get_cloud_vlans},
        "post_create_cloud_vlan": {"2.1.1-2.3.5": post_create_cloud_vlan},
        "get_cloud_vlan": {"2.1.1-2.3.5": get_cloud_vlan},
        "put_update_cloud_vlan": {"2.1.1-2.3.5": put_update_cloud_vlan},
        "delete_cloud_vlan": {"2.1.1-2.3.5": delete_cloud_vlan},
        "get_virtual_networks": {"2.1.1-2.3.5": get_virtual_networks},
        "post_create_virtual_network": {"2.1.1-2.3.5": post_create_virtual_network},
        "get_virtual_network": {"2.1.1-2.3.5": get_virtual_network},
        "put_update_virtual_network": {"2.1.1-2.3.5": put_update_virtual_network},
        "delete_virtual_network": {"2.1.1-2.3.5": delete_virtual_network},
        "get_export_virtual_networks": {"2.1.1-2.3.5": get_export_virtual_networks},
        "post_import_virtual_networks": {"2.1.1-2.3.5": post_import_virtual_networks},
        "get_vns3_topologies": {"2.1.1-2.3.5": get_vns3_topologies},
        "post_create_vns3_topology": {"2.1.1-2.3.5": post_create_vns3_topology},
        "get_vns3_topology": {"2.1.1-2.3.5": get_vns3_topology},
        "put_update_vns3_topology": {"2.1.1-2.3.5": put_update_vns3_topology},
        "delete_vns3_topology": {"2.1.1-2.3.5": delete_vns3_topology},
        "get_webhooks": {"2.3.3-2.3.5": get_webhooks},
        "post_create_webhook": {"2.3.3-2.3.5": post_create_webhook},
        "get_webhook": {"2.3.3-2.3.5": get_webhook},
        "put_update_webhook": {"2.3.3-2.3.5": put_update_webhook},
        "delete_webhook": {"2.3.3-2.3.5": delete_webhook},
        "get_alerts": {"2.3.3-2.3.5": get_alerts},
        "get_alert": {"2.3.3-2.3.5": get_alert},
        "post_create_alert": {"2.3.3-2.3.5": post_create_alert},
        "put_update_alert": {"2.3.3-2.3.5": put_update_alert},
        "delete_alert": {"2.3.3-2.3.5": delete_alert},
        "post_toggle_enable_alert": {"2.3.3-2.3.5": post_toggle_enable_alert},
        "post_test_alert": {"2.3.3-2.3.5": post_test_alert},
    }



# coding: utf-8

"""
    VNS3:ms API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import pytest

import cohesivenet
from cohesivenet.api.vns3ms import access_api  # noqa: E501
from cohesivenet.rest import ApiException

from tests.openapi import generate_method_test
from tests.vns3ms.stub_data import AccessApiData


class TestMSAccessApi(object):
    """AccessApi unit tests"""

    def test_put_activate_api_key(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for put_activate_api_key
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/auth/activate",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(access_api.put_activate_api_key)

    def test_post_create_token(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for post_create_token
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "POST",
            "/auth",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=AccessApiData.TokenResponse,
        )(access_api.post_create_token)

    def test_put_expire_token(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for put_expire_token
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/auth/expire_token",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=AccessApiData.ExpireTokenResponse,
        )(access_api.put_expire_token)

    def test_put_invalidate_api_key_tokens(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for put_invalidate_api_key_tokens
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/auth/invalidate_tokens",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=AccessApiData.ExpireKeyTokens,
        )(access_api.put_invalidate_api_key_tokens)

    def test_get_api_keys(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for get_api_keys
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/auth/api_keys",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=AccessApiData.ApiKeysResponse,
        )(access_api.get_api_keys)

    def test_post_create_api_key(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for post_create_api_key
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "POST",
            "/auth/api_key",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=AccessApiData.NewApiKeyResponse,
        )(access_api.post_create_api_key)

    def test_put_update_api_key(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for put_update_api_key
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/auth/api_key/{key_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=AccessApiData.ApiKeyUpdatedResponse,
        )(access_api.put_update_api_key)

    def test_delete_api_key(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for delete_api_key
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "DELETE",
            "/auth/api_key/{key_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={"response_type": "success", "response": "Deleted key"},
        )(access_api.delete_api_key)



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import pytest

import cohesivenet
from cohesivenet.api.vns3 import bgp_api
from cohesivenet.rest import ApiException

from tests.openapi import generate_method_test
from tests.vns3.stub_data import IpsecApiData, BGPApiData


class TestBGPApi(object):
    """BGPApi unit tests stubs"""

    def test_get_bgp_peer(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for delete_bgp_peer
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "get",
            "/ipsec/endpoints/{endpoint_id}/ebgp_peers/{bgp_peer_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=BGPApiData.BGPPeerDetail,
        )(bgp_api.get_bgp_peer)

    def test_delete_bgp_peer(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for delete_bgp_peer
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "delete",
            "/ipsec/endpoints/{endpoint_id}/ebgp_peers/{bgp_peer_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=IpsecApiData.IpsecEndpointDetail,
        )(bgp_api.delete_bgp_peer)

    def test_create_bgp_peer(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for test_create_bgp_peer
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "post",
            "/ipsec/endpoints/{endpoint_id}/ebgp_peers",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=IpsecApiData.IpsecEndpointDetail,
        )(bgp_api.create_bgp_peer)

    def test_update_bgp_peer(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for test_update_bgp_peer
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "put",
            "/ipsec/endpoints/{endpoint_id}/ebgp_peers/{bgp_peer_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=IpsecApiData.IpsecEndpointDetail,
        )(bgp_api.update_bgp_peer)



VERSION = "0.1.37"
LATEST_VNS3_VERSION = "4.10.1"
LATEST_VNS3_API_SPEC = (
    "https://cohesive-networks.s3.amazonaws.com/apis/vns3/vns3-v%s.oasv3.json"
    % LATEST_VNS3_VERSION.replace(".", "-")
)
LATEST_VNS3_MS_VERSION = "2.3.5"
LATEST_VNS3_MS_API_SPEC = (
    "https://cohesive-networks.s3.amazonaws.com/apis/vns3-ms/vns3ms-v%s.oasv3.json"
    % LATEST_VNS3_MS_VERSION.replace(".", "-")
)



# coding: utf-8

"""
    VNS3:ms API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import pytest

import cohesivenet
from cohesivenet.api.vns3ms import user_api  # noqa: E501
from cohesivenet.rest import ApiException

from tests.openapi import generate_method_test
from tests.vns3ms.stub_data import UserApiData


class TestMSUserApi(object):
    """VNS3:ms User API unit tests"""

    def test_put_user_password(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for put_user_password
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/user/password",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(user_api.put_user_password)

    def test_get_user_credentials(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for get_user_credentials
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "GET",
            "/user/credentials",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=UserApiData.CredsList,
        )(user_api.get_user_credentials)

    def test_post_create_user_credential(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for post_create_user_credential
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "POST",
            "/user/credentials",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response={
                "response_type": "success",
                "response": {"message": "User credentials saved. Validating.", "id": 1},
            },
        )(user_api.post_create_user_credential)

    def test_put_update_user_credential(
        self, rest_mocker, ms_client, ms_api_schema: dict
    ):
        """Test case for put_update_user_credential
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "PUT",
            "/user/credentials/{credential_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(user_api.put_update_user_credential)

    def test_delete_user_credential(self, rest_mocker, ms_client, ms_api_schema: dict):
        """Test case for delete_user_credential
        """
        generate_method_test(
            ms_client,
            ms_api_schema,
            "DELETE",
            "/user/credentials/{credential_id}",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response_from_schema=True,
        )(user_api.delete_user_credential)



# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import pytest

import cohesivenet
from cohesivenet.api.vns3 import licensing_api  # noqa: E501
from cohesivenet.rest import ApiException

from tests.openapi import generate_method_test
from tests.vns3.stub_data import LicensingApiData


class TestLicensingApi(object):
    """LicensingApi unit test stubs"""

    def test_get_license(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for get_license
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "get",
            "/license",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=LicensingApiData.LicenseDetail,
        )(licensing_api.get_license)

    def test_put_license_upgrade(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for put_license_upgrade

        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "put",
            "/license/upgrade",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=LicensingApiData.UpgradeLicenseResponse,
        )(licensing_api.put_license_upgrade)

    def test_put_set_license_parameters(
        self, rest_mocker, vns3_client, vns3_api_schema: dict
    ):
        """Test case for put_set_license_parameters
        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "put",
            "/license/parameters",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=LicensingApiData.LicenseParamsResponse,
        )(licensing_api.put_set_license_parameters)

    def test_upload_license(self, rest_mocker, vns3_client, vns3_api_schema: dict):
        """Test case for upload_license

        """
        generate_method_test(
            vns3_client,
            vns3_api_schema,
            "put",
            "/license",
            rest_mocker,
            mock_request_from_schema=True,
            mock_response=LicensingApiData.LicenseUploadDetail,
        )(licensing_api.upload_license)
